@@ -53,6 +53,26 @@ class StateMachine():
     def verbose(self, val):
         self._verbose = val
 
+    def arrive_sequence(self, next_state_name):
+        """arrive(next_state_name) の拡張版。
+        このステートを通り過ぎる指定があったなら、次の leave(...) まで行います。
+        通り過ぎる指定がなくなるまで続けます
+
+        Parameters
+        ----------
+        str : next_state_name
+            次の状態の名前
+        """
+        interrupt_line = self.arrive(next_state_name)
+
+        # interrupt_line の指定があったら、次の leave をすぐ行います
+        while interrupt_line:
+            next_state_name, transition_key = self.leave(
+                interrupt_line)
+
+            interrupt_line = self.arrive(
+                next_state_name)
+
     def arrive(self, next_state_name):
         """指定の状態に遷移します
         on_entryコールバック関数を呼び出します。
@@ -61,6 +81,11 @@ class StateMachine():
         ----------
         str : next_state_name
             次の状態の名前
+
+        Returns
+        -------
+        object
+            ただちに leave に渡したい引数。無ければ None
         """
 
         if self.verbose:
@@ -70,14 +95,12 @@ class StateMachine():
             # 次のステートへ引継ぎ
             self._state = self._state_creator_dict[next_state_name]()
 
-            self._state.on_entry(self._context)
+            interrupt_line = self._state.on_entry(self._context)
+            if interrupt_line and self.verbose:
+                print(
+                    f"[state_machine] Arrive interrupt_line={interrupt_line}")
 
-            # このステートをただちに通り過ぎたいなら
-            line = self._state.pass_on(self._context)
-            if line:
-                if self.verbose:
-                    print(f"[state_machine] Arrive pass_on line={line}")
-                self.leave(line)
+            return interrupt_line
 
         else:
             # Error
